# Document with Broken Links

This document references [[Exists]] which is available.

But it also references [[Missing Document]] which doesn't exist.

And [[Another Missing]] that also doesn't exist.